@@ -19,11 +19,9 @@
 
 Mail::SpamAssassin::BayesStore::Redis - Redis Bayesian Storage Module Implementation
 
-=head1 SYNOPSIS
-
 =head1 DESCRIPTION
 
-This module implementes a Redis based bayesian storage module.
+This module implements a Redis based bayesian storage module.
 
 Apache SpamAssassin v3.4.0 introduces support for keeping
 a Bayes database on a Redis server, either running locally, or accessed
@@ -118,27 +116,19 @@ package Mail::SpamAssassin::BayesStore::Redis;
 
 use strict;
 use warnings;
-use bytes;
+# use bytes;
 use re 'taint';
 use Errno qw(EBADF);
-use Mail::SpamAssassin::Util qw(untaint_var);
-use Mail::SpamAssassin::Timeout;
+use Digest::SHA qw(sha1);
 
-BEGIN {
-  eval { require Digest::SHA; import Digest::SHA qw(sha1); 1 }
-  or do { require Digest::SHA1; import Digest::SHA1 qw(sha1) }
-}
-
-use Mail::SpamAssassin::Logger;
 use Mail::SpamAssassin::BayesStore;
+use Mail::SpamAssassin::Logger;
+use Mail::SpamAssassin::Timeout;
+use Mail::SpamAssassin::Util qw(untaint_var);
 use Mail::SpamAssassin::Util::TinyRedis;
 
-use vars qw( @ISA $VERSION );
-
-BEGIN {
-  $VERSION = 0.09;
-  @ISA = qw( Mail::SpamAssassin::BayesStore );
-}
+our $VERSION = 0.09;
+our @ISA = qw( Mail::SpamAssassin::BayesStore );
 
 =head1 METHODS
 
@@ -644,7 +634,7 @@ sub remove_running_expire_tok {
 public instance (Integer, Integer, Integer) tok_get (String $token)
 
 Description:
-This method retrieves a specificed token (C<$token>) from the database
+This method retrieves a specified token (C<$token>) from the database
 and returns its spam_count, ham_count and last access time.
 
 =cut
@@ -930,7 +920,7 @@ sub tok_touch_all {
 public instance (Boolean) cleanup ()
 
 Description:
-This method perfoms any cleanup necessary before moving onto the next
+This method performs any cleanup necessary before moving onto the next
 operation.
 
 =cut
